# BlitzMeets

BlitzMeets is a python package that wraps around Brei.fi/ng to programmatically create unique meeting urls and also generate QR codes for them for easy sharing.

## Installation

```bash
pip install blitzmeets
```

## Usage
refer to [examples](    https://github.com/BlitzJB/BlitzMeets/tree/main/examples)

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change. /s